==> 10.7.0.zip: webid-video-ident-plugin-spm/Package.swift <==
// swift-tools-version:5.3
// The swift-tools-version declares the minimum version of Swift required to build this package.

import PackageDescription

let package = Package(
    name: "WebIdVideoIdentPlugin",
    platforms: [
        .iOS(.v13)
    ],
    products: [
        // Products define the executables and libraries a package produces, and make them visible to other packages.
        .library(name: "WebIdVideoIdentPlugin", targets: ["WebIdVideoIdentPluginWrapper"]),
    ],
    dependencies: [
        // Dependencies declare other packages that this package depends on.
        .package(
            name: "DeviceKit",
            url: "https://github.com/devicekit/DeviceKit.git",
            .exact("5.2.2")
        ),
        .package(
            name: "AhoyKit",
            url: "https://github.com/ahoyconference/ahoykit-swift",
            .exact("6.1.0")
        ),
        .package(
            name: "WebIdPluginCore",
            url: "https://api.webid-solutions.de/releases/ios/spm/SwiftPackages/webid-plugin-core-spm.git",
            .exact("12.3.1")
        ),
        .package(
            name: "AhoyWebRTC",
            url: "https://github.com/ahoyconference/ahoywebrtc-swift.git",
            .exact("1.8.0")
        )
    ],
    targets: [
        .binaryTarget(
            name: "WebIdVideoIdentPlugin",
            url: "https://api.webid-solutions.de/releases/ios/xcframework/internal/de/webid-solutions/WebIdVideoIdentPlugin/10.7.0/WebIdVideoIdentPlugin.framework-v10.7.0.zip",
            checksum: "45abd831e62ce8d4c9d5fd8d1770b4ce02aa4c54a74bdb50e25d160c61659b6d"
        ),
        .target(
            name: "WebIdVideoIdentPluginWrapper",
            dependencies: [
                .target(name: "WebIdVideoIdentPlugin"),
                // [target dependecies here]
                
                .product(name: "DeviceKit", package: "DeviceKit"),
                .product(name: "AhoyKit", package: "AhoyKit"),
                .product(name: "WebIdPluginCore", package: "WebIdPluginCore"),
                .product(name: "AhoyWebRTC", package: "AhoyWebRTC"),
            ]
        )
    ],
    swiftLanguageVersions: [SwiftVersion.v5]
)

==> 11.4.1.zip: webid-video-ident-plugin-spm/Package.swift <==
// swift-tools-version:5.3
// The swift-tools-version declares the minimum version of Swift required to build this package.

import PackageDescription

let package = Package(
    name: "WebIdVideoIdentPlugin",
    platforms: [
        .iOS(.v13)
    ],
    products: [
        // Products define the executables and libraries a package produces, and make them visible to other packages.
        .library(name: "WebIdVideoIdentPlugin", targets: ["WebIdVideoIdentPluginWrapper"]),
    ],
    dependencies: [
        // Dependencies declare other packages that this package depends on.
        .package(
            name: "WebIdPluginCore",
            url: "https://api.webid-solutions.de/releases/ios/spm/SwiftPackageRedesignV4/webid-plugin-core-spm.git",
            .exact("13.5.1")
        ),
        .package(
            name: "DeviceKit",
            url: "https://github.com/devicekit/DeviceKit.git",
            .exact("5.2.2")
        ),
        .package(
            name: "AhoyKit",
            url: "https://github.com/ahoyconference/ahoykit-swift",
            .exact("6.1.0")
        ),
        .package(
            name: "AhoyWebRTC",
            url: "https://github.com/ahoyconference/ahoywebrtc-swift.git",
            .exact("1.8.0")
        )
    ],
    targets: [
        .binaryTarget(
            name: "WebIdVideoIdentPlugin",
            url: "https://api.webid-solutions.de/releases/ios/xcframework/redesign-v4/de/webid-solutions/WebIdVideoIdentPlugin/11.4.1/WebIdVideoIdentPlugin.framework-v11.4.1.zip",
            checksum: "213986804ddc6e882254d2f096a3b9d6c7494c126c3a3e3efab699c7266f4aca"
        ),
        .target(
            name: "WebIdVideoIdentPluginWrapper",
            dependencies: [
                .target(name: "WebIdVideoIdentPlugin"),
                // [target dependecies here]
                
                .product(name: "WebIdPluginCore", package: "WebIdPluginCore"),
                .product(name: "DeviceKit", package: "DeviceKit"),
                .product(name: "AhoyKit", package: "AhoyKit"),
                .product(name: "AhoyWebRTC", package: "AhoyWebRTC"),
            ]
        )
    ],
    swiftLanguageVersions: [SwiftVersion.v5]
)
